@@ -125,7 +125,10 @@ run (void *cls)
   GtkWidget *main_window;
 
   ml = cls;
-  if (GNUNET_OK != GNUNET_GTK_main_loop_build_window (ml, NULL))
+  if (GNUNET_OK !=
+      GNUNET_GTK_main_loop_build_window (GNUNET_GTK_project_data (),
+                                         ml,
+                                         NULL))
     return;
   cfg = GNUNET_CONFIGURATION_dup (
     GNUNET_GTK_main_loop_get_gtk_configuration (ml));
@@ -134,7 +137,6 @@ run (void *cls)
                                            "CONVERSATION",
                                            "LINE",
                                            line);
-  GNUNET_GTK_set_icon_search_path ();
   GNUNET_GTK_setup_nls ();
   /* setup main window */
   main_window = GTK_WIDGET (
