@@ -31,10 +31,11 @@
  * This displays an about window
  */
 void
-gnunet_conversation_gtk_about_imagemenuitem_activate_cb (GtkWidget * dummy,
+gnunet_conversation_gtk_about_imagemenuitem_activate_cb (GtkWidget *dummy,
                                                          gpointer data)
 {
-  GNUNET_GTK_display_about ("gnunet_conversation_gtk_about_window.glade");
+  GNUNET_GTK_display_about (GNUNET_GTK_project_data (),
+                            "gnunet_conversation_gtk_about_window.glade");
 }
 
 
