@@ -171,7 +171,7 @@ gnunet_conversation_gtk_ego_copy_button_clicked_cb (GtkButton *button,
 {
   struct GNUNET_IDENTITY_Ego *ego;
   const gchar *label;
-  struct GNUNET_IDENTITY_PublicKey pub;
+  struct GNUNET_CRYPTO_PublicKey pub;
   const char *zkey;
   char *uri;
   GtkClipboard *cb;
