@@ -81,8 +81,9 @@ handle_existing_records (void *cls,
     return;
   }
   b_add = GTK_WIDGET (gtk_builder_get_object (
-    builder,
-    "gnunet_conversation_gtk_enter_label_dialog_add_button"));
+                        builder,
+                        "gnunet_conversation_gtk_enter_label_dialog_add_button")
+                      );
   gtk_widget_set_sensitive (b_add, TRUE);
 }
 
@@ -117,8 +118,9 @@ gnunet_conversation_gtk_enter_label_entry_changed_cb (GtkEditable *editable,
                             ("gnunet_conversation_gtk_enter_label_entry")));
   label = gtk_entry_get_text (label_entry);
   b_add = GTK_WIDGET (gtk_builder_get_object (
-    builder,
-    "gnunet_conversation_gtk_enter_label_dialog_add_button"));
+                        builder,
+                        "gnunet_conversation_gtk_enter_label_dialog_add_button")
+                      );
   gtk_widget_set_sensitive (b_add, FALSE);
   if (GNUNET_OK != GNUNET_DNSPARSER_check_label (label))
   {
@@ -227,7 +229,8 @@ gnunet_conversation_gtk_enter_label_window_delete_event_cb (GtkWidget *widget,
  * @param label suggested label (user can change)
  */
 void
-GSC_get_label_for_name (const char *name, const char *label)
+GSC_get_label_for_name (const char *name,
+                        const char *label)
 {
   GtkBuilder *builder;
   GtkWidget *dialog;
@@ -236,7 +239,8 @@ GSC_get_label_for_name (const char *name, const char *label)
   GtkWidget *address_entry;
 
   builder =
-    GNUNET_GTK_get_new_builder ("gnunet_conversation_gtk_enter_label.glade",
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_conversation_gtk_enter_label.glade",
                                 NULL);
   if (NULL == builder)
   {
