@@ -199,7 +199,7 @@ struct IncomingCall
   /**
    * Public key identifying the caller.
    */
-  struct GNUNET_CRYPTO_EcdsaPublicKey caller_id;
+  struct GNUNET_CRYPTO_PublicKey caller_id;
 
   /**
    * Caller ID as human-readable string.
@@ -849,7 +849,7 @@ set_incoming_call_state (struct IncomingCall *ic, enum InCallState state)
  */
 static void
 handle_reverse_lookup_result (void *cls,
-                              const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone,
+                              const struct GNUNET_CRYPTO_PrivateKey *zone,
                               const char *label,
                               unsigned int rd_count,
                               const struct GNUNET_GNSRECORD_Data *rd)
@@ -887,7 +887,7 @@ static void
 phone_event_handler (void *cls,
                      enum GNUNET_CONVERSATION_PhoneEventCode code,
                      struct GNUNET_CONVERSATION_Caller *caller,
-                     const struct GNUNET_CRYPTO_EcdsaPublicKey *caller_id)
+                     const struct GNUNET_CRYPTO_PublicKey *caller_id)
 {
   GtkTreeIter iter;
   gboolean valid;
