@@ -295,7 +295,7 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
   GtkComboBox *ns_cb;
   GtkEntry *ns_entry;
   struct GNUNET_CRYPTO_EcdsaPublicKey want;
-  struct GNUNET_IDENTITY_PublicKey pkey;
+  struct GNUNET_CRYPTO_PublicKey pkey;
 
   if (GNUNET_FS_uri_test_chk (uri) || GNUNET_FS_uri_test_loc (uri))
   {
@@ -320,7 +320,7 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
       GNUNET_break (0);
       return;
     }
-    pkey.type = GNUNET_IDENTITY_TYPE_ECDSA;
+    pkey.type = GNUNET_PUBLIC_KEY_TYPE_ECDSA;
     pkey.ecdsa_key = want;
     {
       const char *ns_zkey;
