@@ -81,12 +81,12 @@ add_child (void *cls,
 
     dmeta = GNUNET_FS_meta_data_duplicate (meta);
     GNUNET_FS_meta_data_insert (dmeta,
-                                       "<user>",
-                                       EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
-                                       EXTRACTOR_METAFORMAT_UTF8,
-                                       "text/plain",
-                                       acc->filename,
-                                       strlen (acc->filename) + 1);
+                                "<user>",
+                                EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
+                                EXTRACTOR_METAFORMAT_UTF8,
+                                "text/plain",
+                                acc->filename,
+                                strlen (acc->filename) + 1);
     acc->sr = GNUNET_GTK_add_to_uri_tab (acc->anonymity, dmeta, NULL);
     GNUNET_FS_meta_data_destroy (dmeta);
     return;
@@ -158,7 +158,8 @@ GNUNET_GTK_main_menu_file_open_gnunet_directory_activate_cb (GtkWidget *dummy,
   GtkFileFilter *ff;
 
   builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_open_directory_dialog.glade",
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_open_directory_dialog.glade",
                                 NULL);
   if (NULL == builder)
   {
@@ -178,4 +179,5 @@ GNUNET_GTK_main_menu_file_open_gnunet_directory_activate_cb (GtkWidget *dummy,
   gtk_window_present (GTK_WINDOW (ad));
 }
 
+
 /* end of gnunet-fs-gtk_open-directory.c */
