@@ -236,7 +236,7 @@ struct EditPublicationDialogContext
   /**
    * Briefly used temporary meta data set.
    */
-  struct GNUNET_CONTAINER_MetaData *md;
+  struct GNUNET_FS_MetaData *md;
 
   /**
    * Information about the file being published as seen by the FS-API.
@@ -367,8 +367,8 @@ GNUNET_GTK_edit_publication_metadata_treeview_selection_changed_cb (
   struct EditPublicationDialogContext *ctx = user_data;
 
   gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
-                              ctx->builder,
-                              "GNUNET_GTK_edit_publication_delete_button")),
+                                          ctx->builder,
+                                          "GNUNET_GTK_edit_publication_delete_button")),
                             gtk_tree_selection_get_selected (ts, NULL, NULL));
 }
 
@@ -641,8 +641,8 @@ GNUNET_GTK_edit_publication_keyword_list_treeview_selection_changed_cb (
 
   gtk_widget_set_sensitive (
     GTK_WIDGET (gtk_builder_get_object (
-      ctx->builder,
-      "GNUNET_GTK_edit_publication_keyword_list_del_button")),
+                  ctx->builder,
+                  "GNUNET_GTK_edit_publication_keyword_list_del_button")),
     gtk_tree_selection_get_selected (ts, NULL, NULL));
 }
 
@@ -664,8 +664,8 @@ GNUNET_GTK_edit_publication_keyword_entry_changed_cb (GtkEditable *editable,
   keyword = gtk_entry_get_text (ctx->keyword_entry);
   gtk_widget_set_sensitive (
     GTK_WIDGET (gtk_builder_get_object (
-      ctx->builder,
-      "GNUNET_GTK_edit_publication_keyword_list_add_button")),
+                  ctx->builder,
+                  "GNUNET_GTK_edit_publication_keyword_list_add_button")),
     (strlen (keyword) > 0) ? TRUE : FALSE);
 }
 
@@ -906,13 +906,13 @@ preserve_meta_items (void *cls,
   }
   if (GNUNET_YES == keep)
     GNUNET_break (GNUNET_OK ==
-                  GNUNET_CONTAINER_meta_data_insert (ctx->md,
-                                                     plugin_name,
-                                                     type,
-                                                     format,
-                                                     data_mime_type,
-                                                     data,
-                                                     data_len));
+                  GNUNET_FS_meta_data_insert (ctx->md,
+                                              plugin_name,
+                                              type,
+                                              format,
+                                              data_mime_type,
+                                              data,
+                                              data_len));
   return 0;
 }
 
@@ -954,6 +954,8 @@ le_callback (void *cls,
   }
   return 0;
 }
+
+
 #endif
 
 
@@ -1002,7 +1004,7 @@ static int
 file_information_update (void *cls,
                          struct GNUNET_FS_FileInformation *fi,
                          uint64_t length,
-                         struct GNUNET_CONTAINER_MetaData *meta,
+                         struct GNUNET_FS_MetaData *meta,
                          struct GNUNET_FS_Uri **uri,
                          struct GNUNET_FS_BlockOptions *bo,
                          int *do_index,
@@ -1048,13 +1050,13 @@ file_information_update (void *cls,
   }
 
   /* update meta data; first, we copy the unchanged values from the original meta data */
-  ctx->md = GNUNET_CONTAINER_meta_data_create ();
-  GNUNET_CONTAINER_meta_data_iterate (meta, &preserve_meta_items, ctx);
+  ctx->md = GNUNET_FS_meta_data_create ();
+  GNUNET_FS_meta_data_iterate (meta, &preserve_meta_items, ctx);
   /* clear original meta data */
-  GNUNET_CONTAINER_meta_data_clear (meta);
+  GNUNET_FS_meta_data_clear (meta);
   /* add all of the 'preserved' values */
-  GNUNET_CONTAINER_meta_data_merge (meta, ctx->md);
-  GNUNET_CONTAINER_meta_data_destroy (ctx->md);
+  GNUNET_FS_meta_data_merge (meta, ctx->md);
+  GNUNET_FS_meta_data_destroy (ctx->md);
   ctx->md = NULL;
   /* now add all of the values from the model; adding will simply do
      nothing for values that are already in the set because they were preserved */
@@ -1078,13 +1080,13 @@ file_information_update (void *cls,
                           -1);
       if (ntype > 0)
       {
-        GNUNET_CONTAINER_meta_data_insert (meta,
-                                           "<user>",
-                                           ntype,
-                                           nformat,
-                                           "text/plain",
-                                           value,
-                                           strlen (value) + 1);
+        GNUNET_FS_meta_data_insert (meta,
+                                    "<user>",
+                                    ntype,
+                                    nformat,
+                                    "text/plain",
+                                    value,
+                                    strlen (value) + 1);
       }
       g_free (value);
     } while (
@@ -1102,8 +1104,8 @@ file_information_update (void *cls,
 
     fn =
       gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (gtk_builder_get_object (
-        ctx->builder,
-        "GNUNET_GTK_edit_publication_metadata_preview_file_chooser_button")));
+                                                         ctx->builder,
+                                                         "GNUNET_GTK_edit_publication_metadata_preview_file_chooser_button")));
     f = g_file_new_for_path (fn);
     if (! g_file_load_contents (f, NULL, &data, &data_size, NULL, NULL))
     {
@@ -1134,13 +1136,13 @@ file_information_update (void *cls,
         g_object_unref (finfo);
       }
 #endif
-      GNUNET_CONTAINER_meta_data_insert (meta,
-                                         "<user>",
-                                         EXTRACTOR_METATYPE_THUMBNAIL,
-                                         EXTRACTOR_METAFORMAT_BINARY,
-                                         mime,
-                                         data,
-                                         data_size);
+      GNUNET_FS_meta_data_insert (meta,
+                                  "<user>",
+                                  EXTRACTOR_METATYPE_THUMBNAIL,
+                                  EXTRACTOR_METAFORMAT_BINARY,
+                                  mime,
+                                  data,
+                                  data_size);
       GNUNET_free (mime);
     }
     g_object_unref (f);
@@ -1258,7 +1260,7 @@ static int
 file_information_import (void *cls,
                          struct GNUNET_FS_FileInformation *fi,
                          uint64_t length,
-                         struct GNUNET_CONTAINER_MetaData *meta,
+                         struct GNUNET_FS_MetaData *meta,
                          struct GNUNET_FS_Uri **uri,
                          struct GNUNET_FS_BlockOptions *bo,
                          int *do_index,
@@ -1287,9 +1289,9 @@ file_information_import (void *cls,
   /* import meta data */
   if (NULL != meta)
   {
-    GNUNET_CONTAINER_meta_data_iterate (meta,
-                                        &GNUNET_FS_GTK_add_meta_data_to_list_store,
-                                        ctx->meta_liststore);
+    GNUNET_FS_meta_data_iterate (meta,
+                                 &GNUNET_FS_GTK_add_meta_data_to_list_store,
+                                 ctx->meta_liststore);
     pixbuf = GNUNET_FS_GTK_get_thumbnail_from_meta_data (meta);
     if (pixbuf != NULL)
     {
@@ -1299,9 +1301,9 @@ file_information_import (void *cls,
 
   /* Also update window title based on filename */
   gtk_window_set_title (ctx->edit_publication_window, _ ("<unnamed>"));
-  GNUNET_CONTAINER_meta_data_iterate (meta,
-                                      &set_window_title_to_filename,
-                                      ctx->edit_publication_window);
+  GNUNET_FS_meta_data_iterate (meta,
+                               &set_window_title_to_filename,
+                               ctx->edit_publication_window);
   return GNUNET_SYSERR; /* only visit top-level item */
 }
 
@@ -1340,7 +1342,9 @@ GNUNET_FS_GTK_edit_publish_dialog (GtkWindow *parent,
   ctx->cb_cls = cb_cls;
   ctx->meta_combo_selected_type_id = -1;
   ctx->builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_edit_publication.glade", ctx);
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_edit_publication.glade",
+                                ctx);
 
   if (NULL == ctx->builder)
   {
@@ -1383,11 +1387,12 @@ GNUNET_FS_GTK_edit_publish_dialog (GtkWindow *parent,
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_edit_publication_root_entry"));
   ctx->expiration_year_spin = GTK_SPIN_BUTTON (gtk_builder_get_object (
-    ctx->builder,
-    "GNUNET_GTK_edit_publication_expiration_year_spin_button"));
+                                                 ctx->builder,
+                                                 "GNUNET_GTK_edit_publication_expiration_year_spin_button"));
   ctx->priority_spin = GTK_SPIN_BUTTON (
     gtk_builder_get_object (ctx->builder,
-                            "GNUNET_GTK_edit_publication_priority_spin_button"));
+                            "GNUNET_GTK_edit_publication_priority_spin_button"))
+  ;
   ctx->replication_spin = GTK_SPIN_BUTTON (
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_edit_publication_replication_spin_button"));
