@@ -32,7 +32,7 @@
  */
 static const struct GNUNET_OS_ProjectData gtk_pd = {
   .libname = "libgnunetgtk",
-  .project_dirname = "gnunet", // FIXME: should change to gnunet-gtk eventually!
+  .project_dirname = "gnunet-gtk",
   .binary_name = "gnunet-fs-gtk",
   .env_varname = "GNUNET_GTK_PREFIX",
   .env_varname_alt = "GNUNET_PREFIX",
