@@ -1,22 +1,22 @@
 /*
-  * This file is part of GNUnet
-  * Copyright (C) 2009-2014 GNUnet e.V.
-  *
-  * GNUnet is free software; you can redistribute it and/or modify
-  * it under the terms of the GNU General Public License as published
-  * by the Free Software Foundation; either version 3, or (at your
-  * option) any later version.
-  *
-  * GNUnet is distributed in the hope that it will be useful, but
-  * WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * General Public License for more details.
-  *
-  * You should have received a copy of the GNU General Public License
-  * along with GNUnet; see the file COPYING.  If not, write to the
-  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+ * This file is part of GNUnet
+ * Copyright (C) 2009-2014 GNUnet e.V.
+ *
+ * GNUnet is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your
+ * option) any later version.
+ *
+ * GNUnet is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNUnet; see the file COPYING.  If not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 /**
  * @file namestore/plugin_gtk_namestore_srv.c
  * @brief namestore plugin for editing SRV records
@@ -92,7 +92,7 @@ srv_load (void *cls, gchar *n_value, GtkBuilder *builder)
   char target_name[253 + 1];
   GtkTreeModel *tm;
 
-  if (7 != SSCANF (n_value,
+  if (7 != sscanf (n_value,
                    "%u %u %u %u %u %u %253s",
                    &protocol,
                    &service,
