@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2012 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2012 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -33,9 +33,11 @@
  * @param name name of the plugin to check
  */
 static void
-test_plugin (GtkWidget * widget, const char *name)
+test_plugin (GtkWidget *widget, const char *name)
 {
-  if (GNUNET_YES == GNUNET_PLUGIN_test (name))
+  if (GNUNET_YES ==
+      GNUNET_PLUGIN_test (GNUNET_OS_project_data_gnunet (),
+                          name))
   {
     gtk_widget_set_sensitive (widget, TRUE);
   }
@@ -48,20 +50,19 @@ test_plugin (GtkWidget * widget, const char *name)
 
 
 void
-GNUNET_setup_namestore_sqlite_radiobutton_realize_cb (GtkWidget * widget,
-						      gpointer user_data)
+GNUNET_setup_namestore_sqlite_radiobutton_realize_cb (GtkWidget *widget,
+                                                      gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_namestore_sqlite");
 }
 
 
 void
-GNUNET_setup_namestore_postgres_radiobutton_realize_cb (GtkWidget * widget,
-                                                           gpointer user_data)
+GNUNET_setup_namestore_postgres_radiobutton_realize_cb (GtkWidget *widget,
+                                                        gpointer user_data)
 {
   test_plugin (widget, "libgnunet_plugin_namestore_postgres");
 }
 
 
-
 /* end of gnunet-setup-namestore-plugins.c */
