@@ -27,6 +27,7 @@
 #include "gnunet-setup-options.h"
 #include "gnunet-setup-exit-services.h"
 #include <gnunet/gnunet_util_lib.h>
+#include <gnunet/gnunet_regex_service.h>
 #include <gdk/gdkkeysyms.h>
 
 
@@ -261,10 +262,10 @@ save_text (const void *cls,
  */
 static int
 load_combo_text (const void *cls,
-		 const char *section,
-		 const char *option,
+                 const char *section,
+                 const char *option,
                  const char *value,
-		 GObject * widget,
+                 GObject *widget,
                  const struct GNUNET_CONFIGURATION_Handle *cfg)
 {
   GtkComboBoxText *cb;
@@ -289,10 +290,10 @@ load_combo_text (const void *cls,
  */
 static int
 save_combo_text (const void *cls,
-		 const char *section,
-		 const char *option,
-                 GObject * widget,
-		 struct GNUNET_CONFIGURATION_Handle *cfg)
+                 const char *section,
+                 const char *option,
+                 GObject *widget,
+                 struct GNUNET_CONFIGURATION_Handle *cfg)
 {
   GtkComboBox *cb;
   gchar *c;
@@ -305,6 +306,8 @@ save_combo_text (const void *cls,
   g_free (c);
   return GNUNET_OK;
 }
+
+
 #endif
 
 
@@ -560,7 +563,7 @@ validate_v4_policy (const void *cls, GObject *widget)
 
   entry = GTK_ENTRY (widget);
   text = gtk_entry_get_text (entry);
-  r = GNUNET_TUN_ipv4policy2regex (text);
+  r = GNUNET_REGEX_ipv4policy2regex (text);
   invalid =
     ((strlen (text) > 0) && ((NULL == r) || (text[strlen (text) - 1] != ';')));
   if (invalid)
@@ -619,7 +622,7 @@ validate_v6_policy (const void *cls, GObject *widget)
 
   entry = GTK_ENTRY (widget);
   text = gtk_entry_get_text (entry);
-  r = GNUNET_TUN_ipv6policy2regex (text);
+  r = GNUNET_REGEX_ipv6policy2regex (text);
   invalid =
     ((strlen (text) > 0) && ((NULL == r) || (text[strlen (text) - 1] != ';')));
   if (invalid)
